# CLIEP Python Console Entrypoint Library

This is a small, no sub-dependency system to streamline interfacing with TTYs, using a primary entrypoint function via decorators with
optional automatic argument parsing.

Documentation forthcoming.